OC.L10N.register(
    "logreader",
    {
    "Error parsing log" : "Fel vid tolkning av loggen",
    "Copy" : "Kopiera",
    "Copy raw" : "Kopiera oformaterad",
    "Copy formatted" : "Kopiera formaterad",
    "No server logs" : "Inga serverloggar",
    "One or more entries are hidden by the log level filter" : "En eller flera poster är gömda av loggningsnivåfiltret",
    "Everything is working fine" : "Allting fungerar fint",
    "Level" : "Nivå",
    "App" : "App",
    "Message" : "Meddelande",
    "Time" : "Tid",
    "Log levels" : "Loggnivåer",
    "Log content" : "Logginnehåll",
    "Live update" : "Live-uppdatering",
    "Download logs" : "Ladda ner loggar",
    "Logging" : "Loggar",
    "Log Reader" : "Loggläsare",
    "A log reader for Nextcloud" : "En loggläsare för Nextcloud",
    "Log reader for Nextcloud" : "Loggläsare för Nextcloud",
    "Cased by " : "Orsakat av"
},
"nplurals=2; plural=(n != 1);");
